@@ -28,12 +28,15 @@ from airflow.compat.functools import cached_property
 from airflow.providers.google.cloud.hooks.compute import ComputeEngineHook
 from airflow.providers.google.cloud.hooks.os_login import OSLoginHook
 from airflow.providers.ssh.hooks.ssh import SSHHook
+from airflow.utils.types import NOTSET, ArgNotSet
 
 # Paramiko should be imported after airflow.providers.ssh. Then the import will fail with
 # cannot import "airflow.providers.ssh" and will be correctly discovered as optional feature
 # TODO:(potiuk) We should add test harness detecting such cases shortly
 import paramiko  # isort:skip
 
+CMD_TIMEOUT = 10
+
 
 class _GCloudAuthorizedSSHClient(paramiko.SSHClient):
     """SSH Client that maintains the context for gcloud authorization during the connection"""
@@ -105,6 +108,7 @@ class ComputeEngineSSHHook(SSHHook):
         use_iap_tunnel: bool = False,
         use_oslogin: bool = True,
         expire_time: int = 300,
+        cmd_timeout: int | ArgNotSet = NOTSET,
         **kwargs,
     ) -> None:
         if kwargs.get("delegate_to") is not None:
@@ -124,6 +128,7 @@ class ComputeEngineSSHHook(SSHHook):
         self.use_oslogin = use_oslogin
         self.expire_time = expire_time
         self.gcp_conn_id = gcp_conn_id
+        self.cmd_timeout = cmd_timeout
         self._conn: Any | None = None
 
     @cached_property
@@ -175,6 +180,17 @@ class ComputeEngineSSHHook(SSHHook):
                 self.expire_time,
             )
 
+            if conn.extra is not None:
+                extra_options = conn.extra_dejson
+                if "cmd_timeout" in extra_options and self.cmd_timeout is NOTSET:
+                    if extra_options["cmd_timeout"]:
+                        self.cmd_timeout = int(extra_options["cmd_timeout"])
+                    else:
+                        self.cmd_timeout = None
+
+            if self.cmd_timeout is NOTSET:
+                self.cmd_timeout = CMD_TIMEOUT
+
     def get_conn(self) -> paramiko.SSHClient:
         """Return SSH connection."""
         self._load_connection_config()
