@@ -16,16 +16,23 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Cloud Bigtable operators."""
+from __future__ import annotations
+
 import enum
-from typing import TYPE_CHECKING, Dict, Iterable, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Iterable, Sequence
 
 import google.api_core.exceptions
+from google.cloud.bigtable import enums
 from google.cloud.bigtable.column_family import GarbageCollectionRule
-from google.cloud.bigtable_admin_v2 import enums
 
 from airflow.exceptions import AirflowException
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.bigtable import BigtableHook
+from airflow.providers.google.cloud.links.bigtable import (
+    BigtableClusterLink,
+    BigtableInstanceLink,
+    BigtableTablesLink,
+)
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -39,10 +46,10 @@ class BigtableValidationMixin:
     def _validate_inputs(self):
         for attr_name in self.REQUIRED_ATTRIBUTES:
             if not getattr(self, attr_name):
-                raise AirflowException(f'Empty parameter: {attr_name}')
+                raise AirflowException(f"Empty parameter: {attr_name}")
 
 
-class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
+class BigtableCreateInstanceOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
     """
     Creates a new Cloud Bigtable instance.
     If the Cloud Bigtable instance with the given ID exists, the operator does not
@@ -65,9 +72,6 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
     :param replica_clusters: (optional) A list of replica clusters for the new
         instance. Each cluster dictionary contains an id and a zone.
         Example: [{"id": "replica-1", "zone": "us-west1-a"}]
-    :param replica_cluster_id: (deprecated) The ID for replica cluster for the new
-        instance.
-    :param replica_cluster_zone: (deprecated)  The zone for replica cluster.
     :param instance_type: (optional) The type of the instance.
     :param instance_display_name: (optional) Human-readable name of the instance. Defaults
         to ``instance_id``.
@@ -88,14 +92,15 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
         account from the list granting this role to the originating account (templated).
     """
 
-    REQUIRED_ATTRIBUTES: Iterable[str] = ('instance_id', 'main_cluster_id', 'main_cluster_zone')
+    REQUIRED_ATTRIBUTES: Iterable[str] = ("instance_id", "main_cluster_id", "main_cluster_zone")
     template_fields: Sequence[str] = (
-        'project_id',
-        'instance_id',
-        'main_cluster_id',
-        'main_cluster_zone',
-        'impersonation_chain',
+        "project_id",
+        "instance_id",
+        "main_cluster_id",
+        "main_cluster_zone",
+        "impersonation_chain",
     )
+    operator_extra_links = (BigtableInstanceLink(),)
 
     def __init__(
         self,
@@ -103,18 +108,16 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
         instance_id: str,
         main_cluster_id: str,
         main_cluster_zone: str,
-        project_id: Optional[str] = None,
-        replica_clusters: Optional[List[Dict[str, str]]] = None,
-        replica_cluster_id: Optional[str] = None,
-        replica_cluster_zone: Optional[str] = None,
-        instance_display_name: Optional[str] = None,
-        instance_type: Optional[enums.Instance.Type] = None,
-        instance_labels: Optional[Dict] = None,
-        cluster_nodes: Optional[int] = None,
-        cluster_storage_type: Optional[enums.StorageType] = None,
-        timeout: Optional[float] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        project_id: str | None = None,
+        replica_clusters: list[dict[str, str]] | None = None,
+        instance_display_name: str | None = None,
+        instance_type: enums.Instance.Type | None = None,
+        instance_labels: dict | None = None,
+        cluster_nodes: int | None = None,
+        cluster_storage_type: enums.StorageType | None = None,
+        timeout: float | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         self.project_id = project_id
@@ -122,8 +125,6 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
         self.main_cluster_id = main_cluster_id
         self.main_cluster_zone = main_cluster_zone
         self.replica_clusters = replica_clusters
-        self.replica_cluster_id = replica_cluster_id
-        self.replica_cluster_zone = replica_cluster_zone
         self.instance_display_name = instance_display_name
         self.instance_type = instance_type
         self.instance_labels = instance_labels
@@ -135,7 +136,7 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -148,6 +149,7 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
                 "The instance '%s' already exists in this project. Consider it as created",
                 self.instance_id,
             )
+            BigtableInstanceLink.persist(context=context, task_instance=self)
             return
         try:
             hook.create_instance(
@@ -156,8 +158,6 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
                 main_cluster_id=self.main_cluster_id,
                 main_cluster_zone=self.main_cluster_zone,
                 replica_clusters=self.replica_clusters,
-                replica_cluster_id=self.replica_cluster_id,
-                replica_cluster_zone=self.replica_cluster_zone,
                 instance_display_name=self.instance_display_name,
                 instance_type=self.instance_type,
                 instance_labels=self.instance_labels,
@@ -165,12 +165,13 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
                 cluster_storage_type=self.cluster_storage_type,
                 timeout=self.timeout,
             )
+            BigtableInstanceLink.persist(context=context, task_instance=self)
         except google.api_core.exceptions.GoogleAPICallError as e:
-            self.log.error('An error occurred. Exiting.')
+            self.log.error("An error occurred. Exiting.")
             raise e
 
 
-class BigtableUpdateInstanceOperator(BaseOperator, BigtableValidationMixin):
+class BigtableUpdateInstanceOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
     """
     Updates an existing Cloud Bigtable instance.
 
@@ -201,24 +202,25 @@ class BigtableUpdateInstanceOperator(BaseOperator, BigtableValidationMixin):
         account from the list granting this role to the originating account (templated).
     """
 
-    REQUIRED_ATTRIBUTES: Iterable[str] = ['instance_id']
+    REQUIRED_ATTRIBUTES: Iterable[str] = ["instance_id"]
     template_fields: Sequence[str] = (
-        'project_id',
-        'instance_id',
-        'impersonation_chain',
+        "project_id",
+        "instance_id",
+        "impersonation_chain",
     )
+    operator_extra_links = (BigtableInstanceLink(),)
 
     def __init__(
         self,
         *,
         instance_id: str,
-        project_id: Optional[str] = None,
-        instance_display_name: Optional[str] = None,
-        instance_type: Optional[Union[enums.Instance.Type, enum.IntEnum]] = None,
-        instance_labels: Optional[Dict] = None,
-        timeout: Optional[float] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        project_id: str | None = None,
+        instance_display_name: str | None = None,
+        instance_type: enums.Instance.Type | enum.IntEnum | None = None,
+        instance_labels: dict | None = None,
+        timeout: float | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         self.project_id = project_id
@@ -232,7 +234,7 @@ class BigtableUpdateInstanceOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -250,12 +252,13 @@ class BigtableUpdateInstanceOperator(BaseOperator, BigtableValidationMixin):
                 instance_labels=self.instance_labels,
                 timeout=self.timeout,
             )
+            BigtableInstanceLink.persist(context=context, task_instance=self)
         except google.api_core.exceptions.GoogleAPICallError as e:
-            self.log.error('An error occurred. Exiting.')
+            self.log.error("An error occurred. Exiting.")
             raise e
 
 
-class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
+class BigtableDeleteInstanceOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
     """
     Deletes the Cloud Bigtable instance, including its clusters and all related tables.
 
@@ -280,20 +283,20 @@ class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
         account from the list granting this role to the originating account (templated).
     """
 
-    REQUIRED_ATTRIBUTES = ('instance_id',)  # type: Iterable[str]
+    REQUIRED_ATTRIBUTES = ("instance_id",)  # type: Iterable[str]
     template_fields: Sequence[str] = (
-        'project_id',
-        'instance_id',
-        'impersonation_chain',
+        "project_id",
+        "instance_id",
+        "impersonation_chain",
     )
 
     def __init__(
         self,
         *,
         instance_id: str,
-        project_id: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        project_id: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         self.project_id = project_id
@@ -303,7 +306,7 @@ class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -317,11 +320,11 @@ class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
                 self.project_id,
             )
         except google.api_core.exceptions.GoogleAPICallError as e:
-            self.log.error('An error occurred. Exiting.')
+            self.log.error("An error occurred. Exiting.")
             raise e
 
 
-class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
+class BigtableCreateTableOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
     """
     Creates the table in the Cloud Bigtable instance.
 
@@ -353,24 +356,25 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
         account from the list granting this role to the originating account (templated).
     """
 
-    REQUIRED_ATTRIBUTES = ('instance_id', 'table_id')  # type: Iterable[str]
+    REQUIRED_ATTRIBUTES = ("instance_id", "table_id")  # type: Iterable[str]
     template_fields: Sequence[str] = (
-        'project_id',
-        'instance_id',
-        'table_id',
-        'impersonation_chain',
+        "project_id",
+        "instance_id",
+        "table_id",
+        "impersonation_chain",
     )
+    operator_extra_links = (BigtableTablesLink(),)
 
     def __init__(
         self,
         *,
         instance_id: str,
         table_id: str,
-        project_id: Optional[str] = None,
-        initial_split_keys: Optional[List] = None,
-        column_families: Optional[Dict[str, GarbageCollectionRule]] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        project_id: str | None = None,
+        initial_split_keys: list | None = None,
+        column_families: dict[str, GarbageCollectionRule] | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         self.project_id = project_id
@@ -404,7 +408,7 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
                 return False
         return True
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -421,6 +425,7 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
                 initial_split_keys=self.initial_split_keys,
                 column_families=self.column_families,
             )
+            BigtableTablesLink.persist(context=context, task_instance=self)
         except google.api_core.exceptions.AlreadyExists:
             if not self._compare_column_families(hook, instance):
                 raise AirflowException(
@@ -429,7 +434,7 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
             self.log.info("The table '%s' already exists. Consider it as created", self.table_id)
 
 
-class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
+class BigtableDeleteTableOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
     """
     Deletes the Cloud Bigtable table.
 
@@ -456,12 +461,12 @@ class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
         account from the list granting this role to the originating account (templated).
     """
 
-    REQUIRED_ATTRIBUTES = ('instance_id', 'table_id')  # type: Iterable[str]
+    REQUIRED_ATTRIBUTES = ("instance_id", "table_id")  # type: Iterable[str]
     template_fields: Sequence[str] = (
-        'project_id',
-        'instance_id',
-        'table_id',
-        'impersonation_chain',
+        "project_id",
+        "instance_id",
+        "table_id",
+        "impersonation_chain",
     )
 
     def __init__(
@@ -469,10 +474,10 @@ class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
         *,
         instance_id: str,
         table_id: str,
-        project_id: Optional[str] = None,
-        app_profile_id: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        project_id: str | None = None,
+        app_profile_id: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         self.project_id = project_id
@@ -484,7 +489,7 @@ class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -503,11 +508,11 @@ class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
             # It's OK if table doesn't exists.
             self.log.info("The table '%s' no longer exists. Consider it as deleted", self.table_id)
         except google.api_core.exceptions.GoogleAPICallError as e:
-            self.log.error('An error occurred. Exiting.')
+            self.log.error("An error occurred. Exiting.")
             raise e
 
 
-class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
+class BigtableUpdateClusterOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
     """
     Updates a Cloud Bigtable cluster.
 
@@ -534,14 +539,15 @@ class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
         account from the list granting this role to the originating account (templated).
     """
 
-    REQUIRED_ATTRIBUTES = ('instance_id', 'cluster_id', 'nodes')  # type: Iterable[str]
+    REQUIRED_ATTRIBUTES = ("instance_id", "cluster_id", "nodes")  # type: Iterable[str]
     template_fields: Sequence[str] = (
-        'project_id',
-        'instance_id',
-        'cluster_id',
-        'nodes',
-        'impersonation_chain',
+        "project_id",
+        "instance_id",
+        "cluster_id",
+        "nodes",
+        "impersonation_chain",
     )
+    operator_extra_links = (BigtableClusterLink(),)
 
     def __init__(
         self,
@@ -549,9 +555,9 @@ class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
         instance_id: str,
         cluster_id: str,
         nodes: int,
-        project_id: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        project_id: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         self.project_id = project_id
@@ -563,7 +569,7 @@ class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -574,10 +580,11 @@ class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
 
         try:
             hook.update_cluster(instance=instance, cluster_id=self.cluster_id, nodes=self.nodes)
+            BigtableClusterLink.persist(context=context, task_instance=self)
         except google.api_core.exceptions.NotFound:
             raise AirflowException(
                 f"Dependency: cluster '{self.cluster_id}' does not exist for instance '{self.instance_id}'."
             )
         except google.api_core.exceptions.GoogleAPICallError as e:
-            self.log.error('An error occurred. Exiting.')
+            self.log.error("An error occurred. Exiting.")
             raise e
