@@ -16,7 +16,6 @@
 # under the License.
 from __future__ import annotations
 
-import warnings
 from typing import TYPE_CHECKING, Sequence
 
 from airflow.providers.google.cloud.links.dataform import (
@@ -40,11 +39,11 @@ from google.cloud.dataform_v1beta1.types import (
     WriteFileResponse,
 )
 
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.dataform import DataformHook
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 
 
-class DataformCreateCompilationResultOperator(BaseOperator):
+class DataformCreateCompilationResultOperator(GoogleCloudBaseOperator):
     """
     Creates a new CompilationResult in a given project and location.
 
@@ -56,8 +55,6 @@ class DataformCreateCompilationResultOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -78,7 +75,6 @@ class DataformCreateCompilationResultOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -92,17 +88,11 @@ class DataformCreateCompilationResultOperator(BaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context):
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         result = hook.create_compilation_result(
@@ -117,7 +107,7 @@ class DataformCreateCompilationResultOperator(BaseOperator):
         return CompilationResult.to_dict(result)
 
 
-class DataformGetCompilationResultOperator(BaseOperator):
+class DataformGetCompilationResultOperator(GoogleCloudBaseOperator):
     """
     Fetches a single CompilationResult.
 
@@ -129,8 +119,6 @@ class DataformGetCompilationResultOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -141,7 +129,7 @@ class DataformGetCompilationResultOperator(BaseOperator):
         account from the list granting this role to the originating account (templated).
     """
 
-    template_fields = ("repository_id", "compilation_result_id", "delegate_to", "impersonation_chain")
+    template_fields = ("repository_id", "compilation_result_id", "impersonation_chain")
 
     def __init__(
         self,
@@ -153,7 +141,6 @@ class DataformGetCompilationResultOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -167,17 +154,11 @@ class DataformGetCompilationResultOperator(BaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context):
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         result = hook.get_compilation_result(
@@ -192,7 +173,7 @@ class DataformGetCompilationResultOperator(BaseOperator):
         return CompilationResult.to_dict(result)
 
 
-class DataformCreateWorkflowInvocationOperator(BaseOperator):
+class DataformCreateWorkflowInvocationOperator(GoogleCloudBaseOperator):
     """
     Creates a new WorkflowInvocation in a given Repository.
 
@@ -204,8 +185,6 @@ class DataformCreateWorkflowInvocationOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -215,12 +194,12 @@ class DataformCreateWorkflowInvocationOperator(BaseOperator):
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
     :param asynchronous: Flag to return workflow_invocation_id from the Dataform API.
-        This is useful for submitting long running workflows and
+        This is useful for submitting long-running workflows and
         waiting on them asynchronously using the DataformWorkflowInvocationStateSensor
     :param wait_time: Number of seconds between checks
     """
 
-    template_fields = ("workflow_invocation", "delegate_to", "impersonation_chain")
+    template_fields = ("workflow_invocation", "impersonation_chain")
     operator_extra_links = (DataformWorkflowInvocationLink(),)
 
     def __init__(
@@ -233,7 +212,6 @@ class DataformCreateWorkflowInvocationOperator(BaseOperator):
         timeout: int | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         asynchronous: bool = False,
         wait_time: int = 10,
@@ -249,11 +227,6 @@ class DataformCreateWorkflowInvocationOperator(BaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.asynchronous = asynchronous
         self.wait_time = wait_time
@@ -261,7 +234,6 @@ class DataformCreateWorkflowInvocationOperator(BaseOperator):
     def execute(self, context: Context):
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         result = hook.create_workflow_invocation(
@@ -294,7 +266,7 @@ class DataformCreateWorkflowInvocationOperator(BaseOperator):
         return WorkflowInvocation.to_dict(result)
 
 
-class DataformGetWorkflowInvocationOperator(BaseOperator):
+class DataformGetWorkflowInvocationOperator(GoogleCloudBaseOperator):
     """
     Fetches a single WorkflowInvocation.
 
@@ -306,8 +278,6 @@ class DataformGetWorkflowInvocationOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -318,7 +288,7 @@ class DataformGetWorkflowInvocationOperator(BaseOperator):
         account from the list granting this role to the originating account (templated).
     """
 
-    template_fields = ("repository_id", "workflow_invocation_id", "delegate_to", "impersonation_chain")
+    template_fields = ("repository_id", "workflow_invocation_id", "impersonation_chain")
     operator_extra_links = (DataformWorkflowInvocationLink(),)
 
     def __init__(
@@ -331,7 +301,6 @@ class DataformGetWorkflowInvocationOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -345,17 +314,11 @@ class DataformGetWorkflowInvocationOperator(BaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context):
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         result = hook.get_workflow_invocation(
@@ -370,7 +333,7 @@ class DataformGetWorkflowInvocationOperator(BaseOperator):
         return WorkflowInvocation.to_dict(result)
 
 
-class DataformCancelWorkflowInvocationOperator(BaseOperator):
+class DataformCancelWorkflowInvocationOperator(GoogleCloudBaseOperator):
     """
     Requests cancellation of a running WorkflowInvocation.
 
@@ -382,8 +345,6 @@ class DataformCancelWorkflowInvocationOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -394,7 +355,7 @@ class DataformCancelWorkflowInvocationOperator(BaseOperator):
         account from the list granting this role to the originating account (templated).
     """
 
-    template_fields = ("repository_id", "workflow_invocation_id", "delegate_to", "impersonation_chain")
+    template_fields = ("repository_id", "workflow_invocation_id", "impersonation_chain")
     operator_extra_links = (DataformWorkflowInvocationLink(),)
 
     def __init__(
@@ -407,7 +368,6 @@ class DataformCancelWorkflowInvocationOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -421,17 +381,11 @@ class DataformCancelWorkflowInvocationOperator(BaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context):
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         hook.cancel_workflow_invocation(
@@ -445,7 +399,7 @@ class DataformCancelWorkflowInvocationOperator(BaseOperator):
         )
 
 
-class DataformCreateRepositoryOperator(BaseOperator):
+class DataformCreateRepositoryOperator(GoogleCloudBaseOperator):
     """
     Creates repository.
 
@@ -456,8 +410,6 @@ class DataformCreateRepositoryOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -472,7 +424,6 @@ class DataformCreateRepositoryOperator(BaseOperator):
     template_fields = (
         "project_id",
         "repository_id",
-        "delegate_to",
         "impersonation_chain",
     )
 
@@ -485,7 +436,6 @@ class DataformCreateRepositoryOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -501,17 +451,11 @@ class DataformCreateRepositoryOperator(BaseOperator):
         self.metadata = metadata
 
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> dict:
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
@@ -535,7 +479,7 @@ class DataformCreateRepositoryOperator(BaseOperator):
         return Repository.to_dict(repository)
 
 
-class DataformDeleteRepositoryOperator(BaseOperator):
+class DataformDeleteRepositoryOperator(GoogleCloudBaseOperator):
     """
     Deletes repository.
 
@@ -546,8 +490,6 @@ class DataformDeleteRepositoryOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -561,7 +503,6 @@ class DataformDeleteRepositoryOperator(BaseOperator):
     template_fields = (
         "project_id",
         "repository_id",
-        "delegate_to",
         "impersonation_chain",
     )
 
@@ -575,7 +516,6 @@ class DataformDeleteRepositoryOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -592,17 +532,11 @@ class DataformDeleteRepositoryOperator(BaseOperator):
         self.metadata = metadata
 
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
@@ -617,7 +551,7 @@ class DataformDeleteRepositoryOperator(BaseOperator):
         )
 
 
-class DataformCreateWorkspaceOperator(BaseOperator):
+class DataformCreateWorkspaceOperator(GoogleCloudBaseOperator):
     """
     Creates workspace.
 
@@ -629,8 +563,6 @@ class DataformCreateWorkspaceOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -645,7 +577,6 @@ class DataformCreateWorkspaceOperator(BaseOperator):
     template_fields = (
         "project_id",
         "repository_id",
-        "delegate_to",
         "impersonation_chain",
     )
 
@@ -659,7 +590,6 @@ class DataformCreateWorkspaceOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -676,17 +606,11 @@ class DataformCreateWorkspaceOperator(BaseOperator):
         self.metadata = metadata
 
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> dict:
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
@@ -712,7 +636,7 @@ class DataformCreateWorkspaceOperator(BaseOperator):
         return Workspace.to_dict(workspace)
 
 
-class DataformDeleteWorkspaceOperator(BaseOperator):
+class DataformDeleteWorkspaceOperator(GoogleCloudBaseOperator):
     """
     Deletes workspace.
 
@@ -724,8 +648,6 @@ class DataformDeleteWorkspaceOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -740,7 +662,6 @@ class DataformDeleteWorkspaceOperator(BaseOperator):
         "project_id",
         "repository_id",
         "workspace_id",
-        "delegate_to",
         "impersonation_chain",
     )
 
@@ -754,7 +675,6 @@ class DataformDeleteWorkspaceOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -771,17 +691,11 @@ class DataformDeleteWorkspaceOperator(BaseOperator):
         self.metadata = metadata
 
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
@@ -796,7 +710,7 @@ class DataformDeleteWorkspaceOperator(BaseOperator):
         )
 
 
-class DataformWriteFileOperator(BaseOperator):
+class DataformWriteFileOperator(GoogleCloudBaseOperator):
     """
     Writes new file to specified workspace.
 
@@ -810,8 +724,6 @@ class DataformWriteFileOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -826,7 +738,6 @@ class DataformWriteFileOperator(BaseOperator):
         "project_id",
         "repository_id",
         "workspace_id",
-        "delegate_to",
         "impersonation_chain",
     )
 
@@ -842,7 +753,6 @@ class DataformWriteFileOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -861,17 +771,11 @@ class DataformWriteFileOperator(BaseOperator):
         self.metadata = metadata
 
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> dict:
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         write_file_response = hook.write_file(
@@ -888,7 +792,7 @@ class DataformWriteFileOperator(BaseOperator):
         return WriteFileResponse.to_dict(write_file_response)
 
 
-class DataformMakeDirectoryOperator(BaseOperator):
+class DataformMakeDirectoryOperator(GoogleCloudBaseOperator):
     """
     Makes new directory in specified workspace.
 
@@ -901,8 +805,6 @@ class DataformMakeDirectoryOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -917,7 +819,6 @@ class DataformMakeDirectoryOperator(BaseOperator):
         "project_id",
         "repository_id",
         "workspace_id",
-        "delegate_to",
         "impersonation_chain",
     )
 
@@ -932,7 +833,6 @@ class DataformMakeDirectoryOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -950,17 +850,11 @@ class DataformMakeDirectoryOperator(BaseOperator):
         self.metadata = metadata
 
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> dict:
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
@@ -978,7 +872,7 @@ class DataformMakeDirectoryOperator(BaseOperator):
         return MakeDirectoryResponse.to_dict(make_directory_response)
 
 
-class DataformRemoveFileOperator(BaseOperator):
+class DataformRemoveFileOperator(GoogleCloudBaseOperator):
     """
     Removes file in specified workspace.
 
@@ -991,8 +885,6 @@ class DataformRemoveFileOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1007,7 +899,6 @@ class DataformRemoveFileOperator(BaseOperator):
         "project_id",
         "repository_id",
         "workspace_id",
-        "delegate_to",
         "impersonation_chain",
     )
 
@@ -1022,7 +913,6 @@ class DataformRemoveFileOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -1040,17 +930,11 @@ class DataformRemoveFileOperator(BaseOperator):
         self.metadata = metadata
 
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
@@ -1066,7 +950,7 @@ class DataformRemoveFileOperator(BaseOperator):
         )
 
 
-class DataformRemoveDirectoryOperator(BaseOperator):
+class DataformRemoveDirectoryOperator(GoogleCloudBaseOperator):
     """
     Removes directory in specified workspace.
 
@@ -1079,8 +963,6 @@ class DataformRemoveDirectoryOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1095,7 +977,6 @@ class DataformRemoveDirectoryOperator(BaseOperator):
         "project_id",
         "repository_id",
         "workspace_id",
-        "delegate_to",
         "impersonation_chain",
     )
 
@@ -1110,7 +991,6 @@ class DataformRemoveDirectoryOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -1128,17 +1008,11 @@ class DataformRemoveDirectoryOperator(BaseOperator):
         self.metadata = metadata
 
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
@@ -1154,7 +1028,7 @@ class DataformRemoveDirectoryOperator(BaseOperator):
         )
 
 
-class DataformInstallNpmPackagesOperator(BaseOperator):
+class DataformInstallNpmPackagesOperator(GoogleCloudBaseOperator):
     """
     Installs npm dependencies in the provided workspace. Requires "package.json" to be created in workspace
 
@@ -1166,8 +1040,6 @@ class DataformInstallNpmPackagesOperator(BaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate, if any. For this to work, the service accountmaking the
-        request must have  domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1182,7 +1054,6 @@ class DataformInstallNpmPackagesOperator(BaseOperator):
         "project_id",
         "repository_id",
         "workspace_id",
-        "delegate_to",
         "impersonation_chain",
     )
 
@@ -1196,7 +1067,6 @@ class DataformInstallNpmPackagesOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         *args,
         **kwargs,
@@ -1213,17 +1083,11 @@ class DataformInstallNpmPackagesOperator(BaseOperator):
         self.metadata = metadata
 
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> dict:
         hook = DataformHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
