@@ -18,24 +18,23 @@
 """This module contains Google Datastore operators."""
 from __future__ import annotations
 
-import warnings
 from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.exceptions import AirflowException
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.datastore import DatastoreHook
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
 from airflow.providers.google.cloud.links.datastore import (
     CloudDatastoreEntitiesLink,
     CloudDatastoreImportExportLink,
 )
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 from airflow.providers.google.common.links.storage import StorageLink
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class CloudDatastoreExportEntitiesOperator(BaseOperator):
+class CloudDatastoreExportEntitiesOperator(GoogleCloudBaseOperator):
     """
     Export entities from Google Cloud Datastore to Cloud Storage
 
@@ -46,15 +45,12 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
     .. seealso::
         https://cloud.google.com/datastore/docs/export-import-entities
 
-    :param bucket: name of the cloud storage bucket to backup data
+    :param bucket: name of the cloud storage bucket to back up data
     :param namespace: optional namespace path in the specified Cloud Storage bucket
-        to backup data. If this namespace does not exist in GCS, it will be created.
+        to back up data. If this namespace does not exist in GCS, it will be created.
     :param datastore_conn_id: the name of the Datastore connection id to use
     :param cloud_storage_conn_id: the name of the cloud storage connection id to
         force-write backup
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param entity_filter: description of what data from the project is included in the
         export, refer to
         https://cloud.google.com/datastore/docs/reference/rest/Shared.Types/EntityFilter
@@ -89,7 +85,6 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
         namespace: str | None = None,
         datastore_conn_id: str = "google_cloud_default",
         cloud_storage_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         entity_filter: dict | None = None,
         labels: dict | None = None,
         polling_interval_in_seconds: int = 10,
@@ -101,11 +96,6 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
         super().__init__(**kwargs)
         self.datastore_conn_id = datastore_conn_id
         self.cloud_storage_conn_id = cloud_storage_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.bucket = bucket
         self.namespace = namespace
         self.entity_filter = entity_filter
@@ -126,7 +116,6 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
 
         ds_hook = DatastoreHook(
             gcp_conn_id=self.datastore_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         result = ds_hook.export_to_storage_bucket(
@@ -151,7 +140,7 @@ class CloudDatastoreExportEntitiesOperator(BaseOperator):
         return result
 
 
-class CloudDatastoreImportEntitiesOperator(BaseOperator):
+class CloudDatastoreImportEntitiesOperator(GoogleCloudBaseOperator):
     """
     Import entities from Cloud Storage to Google Cloud Datastore
 
@@ -172,9 +161,6 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
         https://cloud.google.com/datastore/docs/reference/rest/Shared.Types/EntityFilter
     :param labels: client-assigned labels for cloud storage
     :param datastore_conn_id: the name of the connection id to use
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param polling_interval_in_seconds: number of seconds to wait before polling for
         execution status again
     :param impersonation_chain: Optional service account to impersonate using short-term
@@ -206,7 +192,6 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
         entity_filter: dict | None = None,
         labels: dict | None = None,
         datastore_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         polling_interval_in_seconds: float = 10,
         project_id: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
@@ -214,11 +199,6 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
     ) -> None:
         super().__init__(**kwargs)
         self.datastore_conn_id = datastore_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.bucket = bucket
         self.file = file
         self.namespace = namespace
@@ -232,7 +212,6 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
         self.log.info("Importing data from Cloud Storage bucket %s", self.bucket)
         ds_hook = DatastoreHook(
             self.datastore_conn_id,
-            self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         result = ds_hook.import_from_storage_bucket(
@@ -254,7 +233,7 @@ class CloudDatastoreImportEntitiesOperator(BaseOperator):
         return result
 
 
-class CloudDatastoreAllocateIdsOperator(BaseOperator):
+class CloudDatastoreAllocateIdsOperator(GoogleCloudBaseOperator):
     """
     Allocate IDs for incomplete keys. Return list of keys.
 
@@ -267,9 +246,6 @@ class CloudDatastoreAllocateIdsOperator(BaseOperator):
 
     :param partial_keys: a list of partial keys.
     :param project_id: Google Cloud project ID against which to make the request.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -292,7 +268,6 @@ class CloudDatastoreAllocateIdsOperator(BaseOperator):
         *,
         partial_keys: list,
         project_id: str | None = None,
-        delegate_to: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -302,11 +277,6 @@ class CloudDatastoreAllocateIdsOperator(BaseOperator):
         self.partial_keys = partial_keys
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> list:
@@ -322,7 +292,7 @@ class CloudDatastoreAllocateIdsOperator(BaseOperator):
         return keys
 
 
-class CloudDatastoreBeginTransactionOperator(BaseOperator):
+class CloudDatastoreBeginTransactionOperator(GoogleCloudBaseOperator):
     """
     Begins a new transaction. Returns a transaction handle.
 
@@ -335,9 +305,6 @@ class CloudDatastoreBeginTransactionOperator(BaseOperator):
 
     :param transaction_options: Options for a new transaction.
     :param project_id: Google Cloud project ID against which to make the request.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -359,7 +326,6 @@ class CloudDatastoreBeginTransactionOperator(BaseOperator):
         *,
         transaction_options: dict[str, Any],
         project_id: str | None = None,
-        delegate_to: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -369,11 +335,6 @@ class CloudDatastoreBeginTransactionOperator(BaseOperator):
         self.transaction_options = transaction_options
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> str:
@@ -388,7 +349,7 @@ class CloudDatastoreBeginTransactionOperator(BaseOperator):
         return handle
 
 
-class CloudDatastoreCommitOperator(BaseOperator):
+class CloudDatastoreCommitOperator(GoogleCloudBaseOperator):
     """
     Commit a transaction, optionally creating, deleting or modifying some entities.
 
@@ -401,9 +362,6 @@ class CloudDatastoreCommitOperator(BaseOperator):
 
     :param body: the body of the commit request.
     :param project_id: Google Cloud project ID against which to make the request.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -426,7 +384,6 @@ class CloudDatastoreCommitOperator(BaseOperator):
         *,
         body: dict[str, Any],
         project_id: str | None = None,
-        delegate_to: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -436,11 +393,6 @@ class CloudDatastoreCommitOperator(BaseOperator):
         self.body = body
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> dict:
@@ -456,7 +408,7 @@ class CloudDatastoreCommitOperator(BaseOperator):
         return response
 
 
-class CloudDatastoreRollbackOperator(BaseOperator):
+class CloudDatastoreRollbackOperator(GoogleCloudBaseOperator):
     """
     Roll back a transaction.
 
@@ -469,9 +421,6 @@ class CloudDatastoreRollbackOperator(BaseOperator):
 
     :param transaction: the transaction to roll back.
     :param project_id: Google Cloud project ID against which to make the request.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -493,7 +442,6 @@ class CloudDatastoreRollbackOperator(BaseOperator):
         *,
         transaction: str,
         project_id: str | None = None,
-        delegate_to: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -503,11 +451,6 @@ class CloudDatastoreRollbackOperator(BaseOperator):
         self.transaction = transaction
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
@@ -521,7 +464,7 @@ class CloudDatastoreRollbackOperator(BaseOperator):
         )
 
 
-class CloudDatastoreRunQueryOperator(BaseOperator):
+class CloudDatastoreRunQueryOperator(GoogleCloudBaseOperator):
     """
     Run a query for entities. Returns the batch of query results.
 
@@ -534,9 +477,6 @@ class CloudDatastoreRunQueryOperator(BaseOperator):
 
     :param body: the body of the query request.
     :param project_id: Google Cloud project ID against which to make the request.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -558,7 +498,6 @@ class CloudDatastoreRunQueryOperator(BaseOperator):
         *,
         body: dict[str, Any],
         project_id: str | None = None,
-        delegate_to: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -568,11 +507,6 @@ class CloudDatastoreRunQueryOperator(BaseOperator):
         self.body = body
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> dict:
@@ -587,7 +521,7 @@ class CloudDatastoreRunQueryOperator(BaseOperator):
         return response
 
 
-class CloudDatastoreGetOperationOperator(BaseOperator):
+class CloudDatastoreGetOperationOperator(GoogleCloudBaseOperator):
     """
     Gets the latest state of a long-running operation.
 
@@ -599,9 +533,6 @@ class CloudDatastoreGetOperationOperator(BaseOperator):
         https://cloud.google.com/datastore/docs/reference/data/rest/v1/projects.operations/get
 
     :param name: the name of the operation resource.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -622,7 +553,6 @@ class CloudDatastoreGetOperationOperator(BaseOperator):
         self,
         *,
         name: str,
-        delegate_to: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -631,11 +561,6 @@ class CloudDatastoreGetOperationOperator(BaseOperator):
 
         self.name = name
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context):
@@ -647,7 +572,7 @@ class CloudDatastoreGetOperationOperator(BaseOperator):
         return op
 
 
-class CloudDatastoreDeleteOperationOperator(BaseOperator):
+class CloudDatastoreDeleteOperationOperator(GoogleCloudBaseOperator):
     """
     Deletes the long-running operation.
 
@@ -659,9 +584,6 @@ class CloudDatastoreDeleteOperationOperator(BaseOperator):
         https://cloud.google.com/datastore/docs/reference/data/rest/v1/projects.operations/delete
 
     :param name: the name of the operation resource.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -682,7 +604,6 @@ class CloudDatastoreDeleteOperationOperator(BaseOperator):
         self,
         *,
         name: str,
-        delegate_to: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -691,11 +612,6 @@ class CloudDatastoreDeleteOperationOperator(BaseOperator):
 
         self.name = name
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
