@@ -16,10 +16,11 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains operator for uploading local file(s) to GCS."""
+from __future__ import annotations
+
 import os
-import warnings
 from glob import glob
-from typing import TYPE_CHECKING, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
@@ -44,10 +45,7 @@ class LocalFilesystemToGCSOperator(BaseOperator):
         (e.g. /path/to/directory/) (templated)
     :param bucket: The bucket to upload to. (templated)
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :param google_cloud_storage_conn_id: (Deprecated) The connection ID used to connect to Google Cloud.
-        This parameter has been deprecated. You should pass the gcp_conn_id parameter instead.
     :param mime_type: The mime-type string
-    :param delegate_to: The account to impersonate, if any
     :param gzip: Allows for file to be compressed and uploaded as gzip
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -60,10 +58,10 @@ class LocalFilesystemToGCSOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = (
-        'src',
-        'dst',
-        'bucket',
-        'impersonation_chain',
+        "src",
+        "dst",
+        "bucket",
+        "impersonation_chain",
     )
 
     def __init__(
@@ -72,43 +70,32 @@ class LocalFilesystemToGCSOperator(BaseOperator):
         src,
         dst,
         bucket,
-        gcp_conn_id='google_cloud_default',
-        google_cloud_storage_conn_id=None,
-        mime_type='application/octet-stream',
-        delegate_to=None,
+        gcp_conn_id="google_cloud_default",
+        mime_type="application/octet-stream",
         gzip=False,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ):
         super().__init__(**kwargs)
 
-        if google_cloud_storage_conn_id:
-            warnings.warn(
-                "The google_cloud_storage_conn_id parameter has been deprecated. You should pass "
-                "the gcp_conn_id parameter.",
-                DeprecationWarning,
-                stacklevel=3,
-            )
-            gcp_conn_id = google_cloud_storage_conn_id
-
         self.src = src
         self.dst = dst
         self.bucket = bucket
         self.gcp_conn_id = gcp_conn_id
         self.mime_type = mime_type
-        self.delegate_to = delegate_to
         self.gzip = gzip
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         """Uploads a file or list of files to Google Cloud Storage"""
         hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
         filepaths = self.src if isinstance(self.src, list) else glob(self.src)
+        if not filepaths:
+            raise FileNotFoundError(self.src)
         if os.path.basename(self.dst):  # path to a file
             if len(filepaths) > 1:  # multiple file upload
                 raise ValueError(
