@@ -75,7 +75,7 @@ class CloudBuildCreateBuildTrigger(BaseTrigger):
             },
         )
 
-    async def run(self) -> AsyncIterator["TriggerEvent"]:  # type: ignore[override]
+    async def run(self) -> AsyncIterator[TriggerEvent]:  # type: ignore[override]
         """Gets current build execution status and yields a TriggerEvent"""
         hook = self._get_async_hook()
         while True:
